
Permissions by Function
=======================

The table below lists the permission required to execute each function or method in the SDK.

.. permissions-table::


.. seealso::

   The main Arthur docs' `Permissions by REST Endpoint
   <https://docs.arthur.ai/access-control/permissions_by_endpoint.html>`_ page.